@@ -21,9 +21,15 @@ import json
 import logging
 import os
 import typing as t
+import urllib3
+import warnings
 
 import cdsapi
 from ecmwfapi import ECMWFService
+from .config import Config
+
+warnings.simplefilter(
+    "ignore", category=urllib3.connectionpool.InsecureRequestWarning)
 
 
 class Client(abc.ABC):
@@ -37,7 +43,7 @@ class Client(abc.ABC):
         level: Default log level for the client.
     """
 
-    def __init__(self, config: t.Dict, level: int = logging.INFO) -> None:
+    def __init__(self, config: Config, level: int = logging.INFO) -> None:
         """Clients are initialized with the general CLI configuration."""
         self.config = config
         self.logger = logging.getLogger(f'{__name__}.{type(self).__name__}')
@@ -53,6 +59,12 @@ class Client(abc.ABC):
         """Specifies the number of workers to be used per api key for the dataset."""
         pass
 
+    @property
+    @abc.abstractmethod
+    def license_url(self):
+        """Specifies the License URL."""
+        pass
+
 
 class CdsClient(Client):
     """A client to access weather data from the Cloud Data Store (CDS).
@@ -76,11 +88,11 @@ class CdsClient(Client):
     """Name patterns of datasets that are hosted internally on CDS servers."""
     cds_hosted_datasets = {'reanalysis-era'}
 
-    def __init__(self, config: t.Dict, level: int = logging.INFO) -> None:
+    def __init__(self, config: Config, level: int = logging.INFO) -> None:
         super().__init__(config, level)
         self.c = cdsapi.Client(
-            url=config['parameters'].get('api_url', os.environ.get('CDSAPI_URL')),
-            key=config['parameters'].get('api_key', os.environ.get('CDSAPI_KEY')),
+            url=config.kwargs.get('api_url', os.environ.get('CDSAPI_URL')),
+            key=config.kwargs.get('api_key', os.environ.get('CDSAPI_KEY')),
             debug_callback=self.logger.debug,
             info_callback=self.logger.info,
             warning_callback=self.logger.warning,
@@ -90,6 +102,10 @@ class CdsClient(Client):
     def retrieve(self, dataset: str, selection: t.Dict, target: str) -> None:
         self.c.retrieve(dataset, selection, target)
 
+    @property
+    def license_url(self):
+        return 'https://cds.climate.copernicus.eu/api/v2/terms/static/licence-to-use-copernicus-products.pdf'
+
     def num_requests_per_key(self, dataset: str) -> int:
         """Number of requests per key from the CDS API.
 
@@ -156,13 +172,13 @@ class MarsClient(Client):
         level: Default log level for the client.
     """
 
-    def __init__(self, config: t.Dict, level: int = logging.INFO) -> None:
+    def __init__(self, config: Config, level: int = logging.INFO) -> None:
         super().__init__(config, level)
         self.c = ECMWFService(
             "mars",
-            key=config['parameters'].get('api_key', os.environ.get("MARSAPI_KEY")),
-            url=config['parameters'].get('api_url', os.environ.get("MARSAPI_URL")),
-            email=config['parameters'].get('api_email', os.environ.get("MARSAPI_EMAIL")),
+            key=config.kwargs.get('api_key', os.environ.get("MARSAPI_KEY")),
+            url=config.kwargs.get('api_url', os.environ.get("MARSAPI_URL")),
+            email=config.kwargs.get('api_email', os.environ.get("MARSAPI_EMAIL")),
             log=self.logger.debug,
             verbose=True
         )
@@ -171,6 +187,10 @@ class MarsClient(Client):
         with StdoutLogger(self.logger, level=logging.DEBUG):
             self.c.execute(req=selection, target=output)
 
+    @property
+    def license_url(self):
+        return 'https://apps.ecmwf.int/datasets/licences/general/'
+
     def num_requests_per_key(self, dataset: str) -> int:
         """Number of requests per key (or user) for the Mars API.
 
@@ -194,6 +214,10 @@ class FakeClient(Client):
         with open(output, 'w') as f:
             json.dump({dataset: selection}, f)
 
+    @property
+    def license_url(self):
+        return 'lorem ipsum'
+
     def num_requests_per_key(self, dataset: str) -> int:
         return 1
 
